<?php
namespace Teknisa\PED\Factories;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO\Response\Error;

class Ped02900FatorAjusteProdutoFactory {
     protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->connection       = $entityManager->getConnection();
        $this->entityManager    = $entityManager;
    }


    public function realizaCadastramento($row, $response){
        $produtos = $this->buscaProdutos($row['CDARVPRODINI'], $row['CDARVPRODFIN']);
        
        foreach ($produtos as $produto) {
            foreach ($row['CDFATPRECO'] as $cdfatpreco){
                $prodfator = $this->selectProdfator($produto['CDPRODUTO'], $cdfatpreco);
                if (empty($prodfator)){
                    $this->insereProdFator($cdfatpreco, $produto['CDPRODUTO'], $row['VRFATPRECO']);
                }
            }
        }
    }
    
    public function buscaProdutos($prodinic, $prodfina){
        $sql = "SELECT CDPRODUTO 
                    FROM PRODUTO 
                    WHERE CDARVPROD BETWEEN :P_CDPRODINIC AND :P_CDPRODFINA";

        $params = array(
            'P_CDPRODINIC'=>$prodinic,
            'P_CDPRODFINA'=>$prodfina,
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $rows = $std->fetchAll();
        return $rows;
    }
    
    public function selectProdfator($cdproduto, $cdfatpreco){
        $sql = "SELECT *
                    FROM PRODFATOR 
                    WHERE CDPRODUTO = :P_CDPRODUTO AND CDFATPRECO = :P_CDFATPRECO";

        $params = array(
            'P_CDPRODUTO'=>$cdproduto,
            'P_CDFATPRECO'=>$cdfatpreco,
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $row = $std->fetchAll();
        return $row;
    }
    
   /* public function deleteProdfator($cdproduto, $cdfatpreco){
        $sql = "DELETE FROM PRODFATOR 
                WHERE CDPRODUTO = :P_CDPRODUTO 
                AND CDFATPRECO = :P_CDFATPRECO";

        $params = array(
            'P_CDPRODUTO'=>$cdproduto,
            'P_CDFATPRECO'=>$cdfatpreco,
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }*/
    
    public function insereProdFator($cdfatpreco, $cdproduto, $vrfatpreco){
        $sql = "INSERT INTO PRODFATOR (CDFATPRECO, CDPRODUTO, VRFATPRECO, DTINCLUSAO)
            		   VALUES (:P_CDFATPRECO, :P_CDPRODUTO, :P_VRFATPRECO, SYSDATE)";
            
            
        $params = array(
            'P_CDFATPRECO'=>$cdfatpreco,
            'P_CDPRODUTO'=>$cdproduto,
            'P_VRFATPRECO'=>$vrfatpreco,
        );
        
        try{
            $std = $this->connection->prepare($sql);
            // var_dump($std->execute($params));
            $std->execute($params);
        }catch (\Exception $e){
            // var_dump('ERRO'.$e->getMessage());
            $response->setError(new Error("". $e->getMessage(), 500));
        }
    }
}